==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/FlavorDataArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.FlavorDataArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 *
 * @property data Model flavor-specific data.
 */
public data class FlavorDataArgs(
    public val `data`: Output<Map<String, String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.FlavorDataArgs> {
    override fun toJava(): com.pulumi.azurenative.machinelearningservices.inputs.FlavorDataArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.FlavorDataArgs.builder()
            .`data`(
                `data`?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [FlavorDataArgs].
 */
@PulumiTagMarker
public class FlavorDataArgsBuilder internal constructor() {
    private var `data`: Output<Map<String, String>>? = null

    /**
     * @param value Model flavor-specific data.
     */
    @JvmName("fixkkxsqhgvdntyr")
    public suspend fun `data`(`value`: Output<Map<String, String>>) {
        this.`data` = value
    }

    /**
     * @param value Model flavor-specific data.
     */
    @JvmName("pdxxbhsvqyvflheo")
    public suspend fun `data`(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`data` = mapped
    }

    /**
     * @param values Model flavor-specific data.
     */
    @JvmName("hiuadqwmoghkftvv")
    public fun `data`(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`data` = mapped
    }

    internal fun build(): FlavorDataArgs = FlavorDataArgs(
        `data` = `data`,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/FlavorDataArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.FlavorDataArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 *
 * @property data Model flavor-specific data.
 */
public data class FlavorDataArgs(
    public val `data`: Output<Map<String, String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.FlavorDataArgs> {
    override fun toJava(): com.pulumi.azurenative.machinelearningservices.inputs.FlavorDataArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.FlavorDataArgs.builder()
            .`data`(
                `data`?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [FlavorDataArgs].
 */
@PulumiTagMarker
public class FlavorDataArgsBuilder internal constructor() {
    private var `data`: Output<Map<String, String>>? = null

    /**
     * @param value Model flavor-specific data.
     */
    @JvmName("cyuwejeedxbnxwwj")
    public suspend fun `data`(`value`: Output<Map<String, String>>) {
        this.`data` = value
    }

    /**
     * @param value Model flavor-specific data.
     */
    @JvmName("knhnsvhvdfteylpi")
    public suspend fun `data`(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`data` = mapped
    }

    /**
     * @param values Model flavor-specific data.
     */
    @JvmName("cewboxtpmdoipkvp")
    public fun `data`(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`data` = mapped
    }

    internal fun build(): FlavorDataArgs = FlavorDataArgs(
        `data` = `data`,
    )
}
